@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -61,6 +61,15 @@ chxj_get_module_config(const ap_conf_vector_t *cv, const module *m)
 #endif
 }
 
+void
+chxj_set_module_config(ap_conf_vector_t *cv, const module *m, void *val)
+{
+#if defined(CHXJ_TEST)
+#else
+  ap_set_module_config(cv,m,val);
+#endif
+}
+
 
 char *
 chxj_ap_escape_html(apr_pool_t *p, const char *s) 
