@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -26,11 +26,14 @@ chxj_apply_convrule(request_rec *r, apr_array_header_t *convrules)
   chxjconvrule_entry *pp;
   int                ii;
 
+  if (r->main) {
+    return NULL;
+  }
+
   entries = (chxjconvrule_entry *)convrules->elts;
   for (ii = 0; ii < convrules->nelts; ii++) {
     pp = &entries[ii];
 
-    if (r->main) continue;
 
     /* Match */
     if (s_apply_rule(r, pp)) 
@@ -46,15 +49,18 @@ s_apply_rule(request_rec *r, chxjconvrule_entry *pp)
   int   rtn;
   ap_regmatch_t regmatch[AP_MAX_REG_MATCH];
 
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
+
   uri = r->uri;
 
-  DBG(r,"convert rule pattern=[%s] uri=[%s]", pp->pattern, uri);
+  DBG(r,"REQ[%X] convert rule pattern=[%s] uri=[%s]", TO_ADDR(r),pp->pattern, uri);
 
   rtn = ap_regexec((const ap_regex_t *)pp->regexp, uri, AP_MAX_REG_MATCH, (ap_regmatch_t *)regmatch, 0);
   if (rtn == 0) {
     /* Match */
     if (pp->flags & CONVRULE_FLAG_NOTMATCH) {
       /* not match */
+      DBG(r,"REQ[%X] end %s() (unmatch)",TO_ADDR(r),__func__);
       return 0;
     }
   }
@@ -62,11 +68,13 @@ s_apply_rule(request_rec *r, chxjconvrule_entry *pp)
     /* Unmatch */
     if (!(pp->flags & CONVRULE_FLAG_NOTMATCH)) {
       /* not match */
+      DBG(r,"REQ[%X] end %s() (unmatch)",TO_ADDR(r),__func__);
       return 0;
     }
   }
 
   /* Match */
+  DBG(r,"REQ[%X] end %s() (match)",TO_ADDR(r),__func__);
   return 1;
 }
 /*
