@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -433,16 +433,16 @@ chxj_convert_chtml20(
   *dstlen = srclen;
   dst = chxj_qr_code_blob_handler(r, src, (size_t*)dstlen);
   if (dst) {
-    DBG(r,"i found qrcode xml");
+    DBG(r,"REQ[%X] i found qrcode xml", TO_ADDR(r));
     return dst;
   }
-  DBG(r,"not found qrcode xml");
+  DBG(r,"REQ[%X] not found qrcode xml", TO_ADDR(r));
 
   /*--------------------------------------------------------------------------*/
   /* The CHTML structure is initialized.                                      */
   /*--------------------------------------------------------------------------*/
   s_init_chtml20(&chtml20, &doc, r, spec);
-  DBG(r,"init end");
+  DBG(r,"REQ[%X] init end", TO_ADDR(r));
 
   chtml20.entryp = entryp;
   chtml20.cookie = cookie;
@@ -544,14 +544,14 @@ s_chtml20_search_emoji(chtml20_t *chtml20, char *txt, char **rslt)
   r   = chtml20->doc->r;
 
   if (spec == NULL)
-    DBG(r,"spec is NULL");
+    DBG(r,"REQ[%X] spec is NULL", TO_ADDR(r));
 
   for (ee = chtml20->conf->emoji;
        ee;
        ee = ee->next) {
 
     if (ee->imode == NULL) {
-      DBG(r,"emoji->imode is NULL");
+      DBG(r,"REQ[%X] emoji->imode is NULL", TO_ADDR(r));
       continue;
     }
 
@@ -588,7 +588,7 @@ chxj_chtml20_emoji_only_converter(request_rec *r, device_table *spec, const char
   chtml20 = &__chtml20;
   doc     = &__doc;
 
-  DBG(r, "REQ[%X] start chxj_chtml20_emoji_eonly_converter()", (unsigned int)(apr_size_t)r);
+  DBG(r, "REQ[%X] start %s()", TO_ADDR(r),__func__);
   memset(doc,     0, sizeof(Doc));
   memset(chtml20, 0, sizeof(chtml20_t));
 
@@ -629,7 +629,7 @@ chxj_chtml20_emoji_only_converter(request_rec *r, device_table *spec, const char
   }
   chtml20->out = chxj_buffered_write_flush(chtml20->out, &doc->buf);
 
-  DBG(r, "REQ[%X] end chxj_chtml20_emoji_eonly_converter()", (unsigned int)(apr_size_t)r);
+  DBG(r, "REQ[%X] end %s()", TO_ADDR(r),__func__);
   return chtml20->out;
 }
 
