@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -200,7 +200,7 @@ chxj_conv_z2h(request_rec *r, const char *src, apr_size_t *len, chxjconvrule_ent
   int                 z2h_alpha_flag = 0;
   int                 z2h_num_flag = 0;
 
-  DBG(r,"REQ[%X] start chxj_conv_z2h()", (unsigned int)(apr_size_t)r);
+  DBG(r,"REQ[%X] start %s()", TO_ADDR(r),__func__);
 
   if (entryp->action & CONVRULE_Z2H_ON_BIT) {
     z2h_kana_flag = 1;
@@ -221,8 +221,8 @@ chxj_conv_z2h(request_rec *r, const char *src, apr_size_t *len, chxjconvrule_ent
     z2h_num_flag = 0;
   }
   if (z2h_kana_flag == 0 && z2h_alpha_flag == 0 &&  z2h_num_flag == 0) {
-    DBG(r, "REQ[%X] No Z2h flag.", (unsigned int)(apr_size_t)r);
-    DBG(r,"REQ[%X] end chxj_conv_z2h()", (unsigned int)(apr_size_t)r);
+    DBG(r, "REQ[%X] No Z2h flag.", TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()", TO_ADDR(r),__func__);
     return (char *)src;
   }
 
@@ -233,8 +233,8 @@ chxj_conv_z2h(request_rec *r, const char *src, apr_size_t *len, chxjconvrule_ent
 
   obuf = apr_palloc(pool, ilen + 1);
   if (! obuf) {
-    ERR(r,"%s:%d REQ[%X] memory allocation error", __FILE__,__LINE__,(unsigned int)(apr_size_t)r);
-    DBG(r,"REQ[%X] end chxj_conv_z2h()", (unsigned int)(apr_size_t)r);
+    ERR(r,"REQ[%X] %s:%d memory allocation error", TO_ADDR(r), __FILE__,__LINE__);
+    DBG(r,"REQ[%X] end %s()", TO_ADDR(r),__func__);
     return (char*)src;
   }
 
@@ -358,7 +358,7 @@ chxj_conv_z2h(request_rec *r, const char *src, apr_size_t *len, chxjconvrule_ent
   }
   *len = olen;
 
-  DBG(r,"REQ[%X] end chxj_conv_z2h_kana()", (unsigned int)(apr_size_t)r);
+  DBG(r,"REQ[%X] end %s()", TO_ADDR(r),__func__);
   return obuf;
 }
 /*
