@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -31,16 +31,16 @@ chxj_conv_z2h_num(request_rec *r, const char *src, apr_size_t *len, chxjconvrule
   char                *obuf;
   apr_size_t          olen;
 
-  DBG(r,"REQ[%X] start chxj_conv_z2h_num()", (unsigned int)(apr_size_t)r);
+  DBG(r,"REQ[%X] start %s()", TO_ADDR(r),__func__);
 
   if (entryp->action & CONVRULE_Z2H_NUM_OFF_BIT) {
-    DBG(r,"REQ[%X] Detect Z2hNumOff", (unsigned int)(apr_size_t)r);
-    DBG(r,"REQ[%X] end chxj_conv_z2h_num()", (unsigned int)(apr_size_t)r);
+    DBG(r,"REQ[%X] Detect Z2hNumOff", TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()", TO_ADDR(r),__func__);
     return (char *)src;
   }
   if (! (entryp->action & CONVRULE_Z2H_NUM_ON_BIT)) {
-    DBG(r,"REQ[%X] Detect Z2hNumOff", (unsigned int)(apr_size_t)r);
-    DBG(r,"REQ[%X] end chxj_conv_z2h_num()", (unsigned int)(apr_size_t)r);
+    DBG(r,"REQ[%X] Detect Z2hNumOff", TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()", TO_ADDR(r),__func__);
     return (char *)src;
   }
 
@@ -51,7 +51,8 @@ chxj_conv_z2h_num(request_rec *r, const char *src, apr_size_t *len, chxjconvrule
 
   obuf = apr_palloc(pool, ilen + 1);
   if (! obuf) {
-    ERR(r,"%s:%d REQ[%X] memory allocation error", __FILE__,__LINE__,(unsigned int)(apr_size_t)r);
+    ERR(r,"REQ[%X] %s:%d memory allocation error", TO_ADDR(r),__FILE__,__LINE__);
+    DBG(r,"REQ[%X] end %s()", TO_ADDR(r),__func__);
     return (char*)src;
   }
 
@@ -83,7 +84,7 @@ chxj_conv_z2h_num(request_rec *r, const char *src, apr_size_t *len, chxjconvrule
   }
   *len = olen;
 
-  DBG(r,"REQ[%X] end chxj_conv_z2h_num()", (unsigned int)(apr_size_t)r);
+  DBG(r,"REQ[%X] end %s()", TO_ADDR(r),__func__);
   return obuf;
 }
 /*
