@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -34,31 +34,45 @@ chxj_encoding(request_rec *r, const char *src, apr_size_t *len)
   apr_size_t          ilen;
   apr_size_t          olen;
   mod_chxj_config     *dconf;
+  mod_chxj_req_config *req_conf;
   chxjconvrule_entry  *entryp;
   apr_pool_t          *pool;
 
 
-  DBG(r,"start chxj_encoding()");
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
 
   dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
 
   if (dconf == NULL) {
-    DBG(r,"none encoding.");
+    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char*)src;
   }
   if ((int)*len < 0) {
-    ERR(r, "runtime exception: chxj_encoding(): invalid string size.[%d]", (int)*len);
+    ERR(r, "REQ[%X] runtime exception: chxj_encoding(): invalid string size.[%d]", TO_ADDR(r),(int)*len);
+    DBG(r, "REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char *)apr_pstrdup(r->pool, "");
   }
 
-  entryp = chxj_apply_convrule(r, dconf->convrules);
+  req_conf = chxj_get_req_config(r);
+  /*-------------------------------------------------------------------------*/
+  /* already setup entryp if request_conf->user_agent is not null            */
+  /*-------------------------------------------------------------------------*/
+  if (req_conf->user_agent) {
+    entryp = req_conf->entryp;
+  }
+  else {
+    entryp = chxj_apply_convrule(r, dconf->convrules);
+  }
   if (entryp->encoding == NULL) {
-    DBG(r,"none encoding.");
+    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char *)src;
   }
 
   if (STRCASEEQ('n','N',"none", entryp->encoding)) {
-    DBG(r,"none encoding.");
+    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char*)src;
   }
 
@@ -75,36 +89,36 @@ chxj_encoding(request_rec *r, const char *src, apr_size_t *len)
   olen = ilen * 4 + 1;
   spos = obuf = apr_palloc(pool, olen);
   if (obuf == NULL) {
-    DBG(r,"end   chxj_encoding()");
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return ibuf;
   }
-  DBG(r,"encode convert [%s] -> [%s]", entryp->encoding, "CP932");
+  DBG(r,"REQ[%X] encode convert [%s] -> [%s]", TO_ADDR(r),entryp->encoding, "CP932");
 
   memset(obuf, 0, olen);
   cd = iconv_open("CP932", entryp->encoding);
   if (cd == (iconv_t)-1) {
     if (EINVAL == errno) {
-      ERR(r, "The conversion from %s to %s is not supported by the implementation.", entryp->encoding, "CP932");
+      ERR(r, "REQ[%X] The conversion from %s to %s is not supported by the implementation.", TO_ADDR(r),entryp->encoding, "CP932");
     }
     else {
-      ERR(r, "iconv open failed. from:[%s] to:[%s] errno:[%d]", entryp->encoding, "CP932", errno);
+      ERR(r, "REQ[%X] iconv open failed. from:[%s] to:[%s] errno:[%d]", TO_ADDR(r),entryp->encoding, "CP932", errno);
     }
-    DBG(r,"end   chxj_encoding()");
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return ibuf;
   }
   while (ilen > 0) {
     result = iconv(cd, &ibuf, &ilen, &obuf, &olen);
     if (result == (size_t)(-1)) {
       if (E2BIG == errno) {
-        ERR(r, "There is not sufficient room at *outbuf.");
+        ERR(r, "REQ[%X] There is not sufficient room at *outbuf.",TO_ADDR(r));
         break;
       }
       else if (EILSEQ == errno) {
-        ERR(r, "%s:%d An invalid multibyte sequence has been encountered in the input. input:[%s]", __FILE__,__LINE__,ibuf);
+        ERR(r, "REQ[%X] %s:%d An invalid multibyte sequence has been encountered in the input. input:[%s]", TO_ADDR(r),__FILE__,__LINE__,ibuf);
         chxj_convert_illegal_charactor_sequence(r, entryp, &ibuf, &ilen, &obuf, &olen);
       }
       else if (EINVAL == errno) {
-        ERR(r, "An incomplete multibyte sequence has been encountered in the input. input:[%s]", ibuf);
+        ERR(r, "REQ[%X] An incomplete multibyte sequence has been encountered in the input. input:[%s]", TO_ADDR(r),ibuf);
         break;
       }
     }
@@ -112,7 +126,8 @@ chxj_encoding(request_rec *r, const char *src, apr_size_t *len)
   *len = strlen(spos);
   iconv_close(cd);
 
-  DBG(r,"end   chxj_encoding() len=[%d] obuf=[%.*s]", (int)*len, (int)*len, spos);
+  DBG(r,"REQ[%X] len=[%d] obuf=[%.*s]", TO_ADDR(r),(int)*len, (int)*len, spos);
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
   return spos;
 }
 
@@ -127,7 +142,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 2;
-      DBG(r, "passed 2byte.");
+      DBG(r, "REQ[%X] passed 2byte.",TO_ADDR(r));
     }
     else if ((0xf0 & **ibuf) == 0xe0) {
       /* 3byte charactor */
@@ -135,7 +150,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf +=3;
-      DBG(r, "passed 3byte.");
+      DBG(r, "REQ[%X] passed 3byte.",TO_ADDR(r));
     }
     else if ((0xf8 & **ibuf) == 0xf0) {
       /* 4byte charactor */
@@ -143,7 +158,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf +=4;
-      DBG(r, "passed 4byte.");
+      DBG(r, "REQ[%X] passed 4byte.",TO_ADDR(r));
     }
     else if ((0xc0 & **ibuf) == 0x80) {
       /* 1byte charactor */
@@ -151,7 +166,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 1;
-      DBG(r, "passed 1byte.");
+      DBG(r, "REQ[%X] passed 1byte.",TO_ADDR(r));
     }
     else {
       /* unknown charactor */
@@ -159,7 +174,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 1;
-      DBG(r, "passed 1byte.");
+      DBG(r, "REQ[%X] passed 1byte.",TO_ADDR(r));
     }
   }
   else if (STRCASEEQ('e','E', "EUCJP",               entryp->encoding)
@@ -177,7 +192,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf +=3;
-      DBG(r, "passed 3byte.");
+      DBG(r, "REQ[%X] passed 3byte.",TO_ADDR(r));
     }
     else {
       /* 2byte charactor */
@@ -185,7 +200,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 2;
-      DBG(r, "passed 2byte.");
+      DBG(r, "REQ[%X] passed 2byte.",TO_ADDR(r));
     }
   }
   else if (STRCASEEQ('c', 'C', "CP932",     entryp->encoding)
@@ -207,7 +222,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 2;
-      DBG(r, "passed 2byte.");
+      DBG(r, "REQ[%X] passed 2byte.", TO_ADDR(r));
     }
     else {
       /* 1byte charactor */
@@ -215,7 +230,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 1;
-      DBG(r, "passed 1byte.");
+      DBG(r, "REQ[%X] passed 1byte.",TO_ADDR(r));
     }
   }
   else {
@@ -224,11 +239,11 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
     *obuf += 1;
     *olen -= 1;
     *ibuf += 1;
-    DBG(r, "passed 1byte.");
+    DBG(r, "REQ[%X] passed 1byte.", TO_ADDR(r));
   }
   if (ibuf && *ibuf) {
     *ilen = strlen(*ibuf);
-    DBG(r, "new len = [%" APR_SIZE_T_FMT "].", (apr_size_t)*ilen);
+    DBG(r, "REQ[%X] new len = [%" APR_SIZE_T_FMT "].", TO_ADDR(r),(apr_size_t)*ilen);
   }
 }
 
@@ -245,39 +260,50 @@ chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
   apr_size_t          ilen;
   apr_size_t          olen;
   mod_chxj_config     *dconf;
+  mod_chxj_req_config *req_conf;
   chxjconvrule_entry  *entryp;
 
-  DBG(r,"start chxj_rencoding()");
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
 
   if ((int)*len < 0) {
-    ERR(r, "runtime exception: chxj_rencoding(): invalid string size.[%d]", (int)*len);
+    ERR(r, "REQ[%X] runtime exception: chxj_rencoding(): invalid string size.[%d]", TO_ADDR(r),(int)*len);
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char *)apr_pstrdup(r->pool, "");
   }
 
   dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
   if (! dconf) {
-    DBG(r,"none encoding.");
-    DBG(r,"end   chxj_rencoding()");
+    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char*)src;
   }
 
-  entryp = chxj_apply_convrule(r, dconf->convrules);
+  req_conf = chxj_get_req_config(r);
+  /*-------------------------------------------------------------------------*/
+  /* already setup entryp if request_conf->user_agent is not null            */
+  /*-------------------------------------------------------------------------*/
+  if (req_conf->user_agent) {
+    entryp = req_conf->entryp;
+  }
+  else {
+    entryp = chxj_apply_convrule(r, dconf->convrules);
+  }
   if (! entryp->encoding) {
-    DBG(r,"none encoding.");
-    DBG(r,"end   chxj_rencoding()");
+    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char*)src;
   }
 
   if (STRCASEEQ('n','N',"none", entryp->encoding)) {
-    DBG(r,"none encoding.");
-    DBG(r,"end   chxj_rencoding()");
+    DBG(r,"REQ[%X] none encoding.", TO_ADDR(r));
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char*)src;
   }
 
   ilen = *len;
   ibuf = apr_palloc(r->pool, ilen+1);
   if (! ibuf) {
-    DBG(r,"end   chxj_rencoding()");
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return (char*)src;
   }
 
@@ -287,19 +313,19 @@ chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
   olen = ilen * 4 + 1;
   spos = obuf = apr_palloc(r->pool, olen);
   if (! obuf) {
-    DBG(r,"end   chxj_rencoding()");
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return ibuf;
   }
-  DBG(r,"encode convert [%s] -> [%s]", "CP932", entryp->encoding);
+  DBG(r,"REQ[%X] encode convert [%s] -> [%s]", TO_ADDR(r),"CP932", entryp->encoding);
 
   memset(obuf, 0, olen);
 
   cd = iconv_open(entryp->encoding, "CP932");
   if (cd == (iconv_t)-1) {
     if (EINVAL == errno) {
-      ERR(r, "The conversion from %s to %s is not supported by the implementation.", "CP932", entryp->encoding);
+      ERR(r, "REQ[%X] The conversion from %s to %s is not supported by the implementation.", TO_ADDR(r),"CP932", entryp->encoding);
     }
-    DBG(r,"end   chxj_rencoding()");
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     return ibuf;
   }
 
@@ -307,15 +333,15 @@ chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
     result = iconv(cd, &ibuf, &ilen, &obuf, &olen);
     if (result == (size_t)(-1)) {
       if (E2BIG == errno) {
-        ERR(r, "There is not sufficient room at *outbuf");
+        ERR(r, "REQ[%X] There is not sufficient room at *outbuf",TO_ADDR(r));
         break;
       }
       else if (EILSEQ == errno) {
-        ERR(r, "An invalid multibyte sequence has been encountered in the input. input:[%s]", ibuf);
+        ERR(r, "REQ[%X] An invalid multibyte sequence has been encountered in the input. input:[%s]", TO_ADDR(r),ibuf);
         chxj_convert_illegal_charactor_sequence(r, entryp, &ibuf, &ilen, &obuf, &olen);
       }
       else if (EINVAL == errno) {
-        ERR(r, "An incomplete multibyte sequence has been encountered in the input. input:[%s]", ibuf);
+        ERR(r, "REQ[%X] An incomplete multibyte sequence has been encountered in the input. input:[%s]", TO_ADDR(r),ibuf);
         break;
       }
     }
@@ -324,8 +350,8 @@ chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
   *len = strlen(spos);
   iconv_close(cd);
 
-  DBG(r,"end   chxj_rencoding() len=[%d] obuf=[%.*s]", (int)*len, (int)*len, spos);
-
+  DBG(r,"REQ[%X] len=[%d] obuf=[%.*s]", TO_ADDR(r),(int)*len, (int)*len, spos);
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
   return spos;
 }
 
@@ -347,7 +373,7 @@ chxj_encoding_parameter(request_rec *r, const char *value)
 
   int   use_amp_flag;
   
-  DBG(r, "REQ[%X] start chxj_encoding_parameter()", TO_ADDR(r));
+  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
 
   src = apr_pstrdup(r->pool, value);
 
@@ -361,7 +387,7 @@ chxj_encoding_parameter(request_rec *r, const char *value)
 
   spos = strchr(src, '?');
   if (!spos) {
-    DBG(r, "end   chxj_encoding_parameter()");
+    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
     if (anchor_pos) {
       return apr_pstrcat(r->pool, src, "#", anchor, NULL);
     } else {
@@ -448,7 +474,7 @@ chxj_encoding_parameter(request_rec *r, const char *value)
       }
     }
   }
-  DBG(r, "REQ[%X] end   chxj_encoding_parameter()", TO_ADDR(r));
+  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
 
   if (anchor_pos) {
     return apr_pstrcat(r->pool, src_sv, "?", param, "#", anchor, NULL);
